@@ -1,15 +1,15 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "sisyphus" "0.4.0"
+(define-package "sisyphus" "20251101.2122"
   "Create releases of Emacs packages."
   '((emacs    "30.1")
     (compat   "30.1")
     (cond-let "0.2")
     (elx      "2.3")
     (llama    "1.0")
-    (magit    "4.5"))
+    (magit    "4.4"))
   :url "https://github.com/magit/sisyphus"
-  :commit "7774ea7030fb7b2793eff41a8cae1e80c2ed955a"
-  :revdesc "v0.4.0-0-g7774ea7030fb"
+  :commit "8fe6d76d3d31db60149173c1054961c2757c9f74"
+  :revdesc "8fe6d76d3d31"
   :keywords '("git" "tools" "vc")
   :authors '(("Jonas Bernoulli" . "emacs.sisyphus@jonas.bernoulli.dev"))
   :maintainers '(("Jonas Bernoulli" . "emacs.sisyphus@jonas.bernoulli.dev")))
